import React, { useCallback, useMemo } from 'react';
import { TouchableOpacity, View } from 'react-native';
import Animated, { interpolate, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import styles from './styles';
const Y_DISTANCE = 120;

const AnimatedButton = _ref => {
  let {
    onPress = () => null,
    duration = 500,
    style = {},
    direction = 'up',
    children = null,
    renderFlyingContainer = () => null,
    enableScaleAnimation = true,
    position = 'center',
    animationEnabled = true
  } = _ref;
  const animatedValue = useSharedValue(0);
  const getPosition = useCallback(value => {
    switch (value) {
      case 'left':
        return 'flex-start';

      case 'center':
        return 'center';

      case 'right':
        return 'flex-end';

      default:
        return 'center';
    }
  }, []);
  const containerPosition = useMemo(() => getPosition(position), [position]);
  const styleProps = useMemo(() => ({
    position: containerPosition
  }), [containerPosition]);
  const yTranslation = useMemo(() => direction == 'up' ? -Y_DISTANCE : Y_DISTANCE, [direction]);
  const rCStyle = useAnimatedStyle(() => {
    if (!enableScaleAnimation) {
      return {};
    }

    return {
      transform: [{
        scale: interpolate(animatedValue.value, [0, 0.5, 1], [1, 0.8, 1])
      }]
    };
  });
  const rChStyle = useAnimatedStyle(() => {
    return {
      transform: [{
        translateY: interpolate(animatedValue.value, [0, 0.9, 1], [0, yTranslation, 0])
      }],
      opacity: interpolate(animatedValue.value, [0, 0.6, 0.8, 0.81, 1], [0, 1, 0.5, 0, 0])
    };
  });
  const handleOnPress = useCallback(() => {
    if (animationEnabled) animatedValue.value = withTiming(1, {
      duration
    }, isFinished => {
      if (isFinished) {
        animatedValue.value = 0;
      }
    });
    onPress === null || onPress === void 0 ? void 0 : onPress();
  }, [animationEnabled, duration, onPress]);
  return /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Animated.View, {
    style: [rCStyle]
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: style,
    activeOpacity: 0.8,
    onPress: handleOnPress
  }, children)), /*#__PURE__*/React.createElement(Animated.View, {
    pointerEvents: 'none',
    style: [styles(styleProps).childContainer, rChStyle]
  }, (renderFlyingContainer === null || renderFlyingContainer === void 0 ? void 0 : renderFlyingContainer()) || children || /*#__PURE__*/React.createElement(View, {
    style: style
  })));
};

export default AnimatedButton;
//# sourceMappingURL=index.js.map